#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-expand-syns
version:              0.4.8.0
visibility:           public
id:                   th-expand-syns-0.4.8.0-LtRNSI7BRqeJXQujlt8rna
key:                  th-expand-syns-0.4.8.0-LtRNSI7BRqeJXQujlt8rna
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Daniel Schüssler
homepage:             https://github.com/DanielSchuessler/th-expand-syns
synopsis:             Expands type synonyms in Template Haskell ASTs
description:          Expands type synonyms in Template Haskell ASTs.
category:             Template Haskell
abi:                  68f3f7cdb38efbc63190cbbbb3c9401d
exposed:              True
exposed-modules:      Language.Haskell.TH.ExpandSyns
hidden-modules:       Language.Haskell.TH.ExpandSyns.SemigroupCompat
import-dirs:          /usr/lib/ghc-8.10.5/site-local/th-expand-syns-0.4.8.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/th-expand-syns-0.4.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/th-expand-syns-0.4.8.0
hs-libraries:         HSth-expand-syns-0.4.8.0-LtRNSI7BRqeJXQujlt8rna
depends:
    base-4.14.2.0 containers-0.6.4.1 syb-0.7.2.1-5ZaH2aS3V5s5i5LSCPBZnH
    template-haskell-2.16.0.0
    th-abstraction-0.4.2.0-5X2XqBZ7rCLBwJXut5dQBZ

haddock-interfaces:
    /usr/share/doc/haskell-th-expand-syns/html/th-expand-syns.haddock

haddock-html:         /usr/share/doc/haskell-th-expand-syns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

